Building QuickFIX

# Windows

Open quickfix_vs12.sln, quickfix_vs14.sln, or quickfix_vs15.sln

Batch build all projects. lib\quickfix.lib and lib\debug\quickfix.lib can be linked into your application. Header files are copied to the include directory.

Compile time options are controlled from the config_windows.h file in the src directory. The following options are supported:

#define HAVE_ODBC 1
Compiles ODBC support into QuickFIX.
#define HAVE_MYSQL 1
Compiles MySQL support into QuickFIX. If you enable this option, the mysql include and library directories must be in the Visual Studio search paths.
#define HAVE_POSTGRESQL 1
Compiles PostgreSQL support into QuickFIX. If you enable this option, the postgres include and library directories must be in the Visual Studio search paths.

# Linux / Solaris / FreeBSD / Mac OS X

    ./configure && ./make

    sudo make install

You can also run configure with the --prefix=<base directory> option to install to a custom location.

./configure options:

--with-python3
Build the Python3 API
--with-ruby
Build the Ruby API
--with-mysql
Compile in mysql support
--with-postgresql
Compile in postgresql support

When using the SUNPro compiler:
CC=<full path to SUNPro CC binary>
CFLAGS=-g -xs
CXX=<full path to SUNPro CC binary>
CXXFLAGS=-g -xs
LD=<full path to SUNPro CC binary>
LDFLAGS=-g -xs -lCstd
AR=<full path to SUNPro CC binary>
AR_FLAGS=-g -xs -xar -o